@@ -32,15 +32,12 @@ class VolumeFeedback : public QObject
 
 public:
     explicit VolumeFeedback(QObject *parent = nullptr);
-    ~VolumeFeedback();
+    ~VolumeFeedback() override;
 
     bool isValid() const;
 
-public slots:
+public Q_SLOTS:
     void play(quint32 sinkIndex);
-
-private:
-    ca_context *m_context = nullptr;
 };
 
 #endif // VOLUMEFEEDBACK_H
